"""bifrost-rag: Production RAG pipeline with vector retrieval and evaluation."""

from bifrost_rag.chunking import (
    Chunk,
    ChunkingStrategy,
    FixedSizeChunker,
    RecursiveChunker,
    SentenceChunker,
)
from bifrost_rag.embeddings import Embedder, VoyageEmbedder
from bifrost_rag.evaluation import EvaluationResult, RAGEvaluator
from bifrost_rag.pipeline import RAGPipeline, RAGResult
from bifrost_rag.retrieval import RetrievalResult, Retriever
from bifrost_rag.store import ChromaStore, Document, VectorStore

__version__ = "0.1.0"

__all__ = [
    "Chunk",
    "ChunkingStrategy",
    "ChromaStore",
    "Document",
    "Embedder",
    "EvaluationResult",
    "FixedSizeChunker",
    "RAGEvaluator",
    "RAGPipeline",
    "RAGResult",
    "RecursiveChunker",
    "RetrievalResult",
    "Retriever",
    "SentenceChunker",
    "VectorStore",
    "VoyageEmbedder",
]
